package com.xxfc.platform.vehicle.biz;



import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.wxiaoqi.security.common.biz.BaseBiz;
import com.github.wxiaoqi.security.common.exception.BaseException;
import com.github.wxiaoqi.security.common.util.process.ResultCode;
import com.xxfc.platform.vehicle.entity.Vehicle;
import com.xxfc.platform.vehicle.entity.VehicleDaysPrice;
import com.xxfc.platform.vehicle.entity.VehicleUseTime;
import com.xxfc.platform.vehicle.mapper.VehicleDaysPriceMapper;
import com.xxfc.platform.vehicle.mapper.VehicleUseTimeMapper;
import com.xxfc.platform.vehicle.pojo.vo.VehicleDaysPriceVo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import tk.mybatis.mapper.entity.Example;

import java.math.BigDecimal;
import java.util.Comparator;
import java.util.List;


@Service
@Slf4j
public class VehicleDaysPriceBiz extends BaseBiz<VehicleDaysPriceMapper, VehicleDaysPrice> {



    @Autowired
    VehicleBiz vehicleBiz;



     public  void  addOrUpd(VehicleDaysPrice vehicleDaysPrice){
         String vehicleId = vehicleDaysPrice.getVehicleId();
         if (StringUtils.isBlank(vehicleId) ){
             throw  new BaseException("参数不能为空", ResultCode.FAILED_CODE);
         }
         Example example = new Example(VehicleDaysPrice.class);
         example.createCriteria().andEqualTo("vehicleId",vehicleId).andEqualTo("isDel",0);
         List<VehicleDaysPrice> list = selectByExample(example);
         if (list.size() > 0){
             VehicleDaysPrice vehicleDaysPrice1 = list.get(0);
             vehicleDaysPrice.setId(vehicleDaysPrice1.getId());
             updateSelectiveById(vehicleDaysPrice);
         }else {
             insertSelective(vehicleDaysPrice);
         }
     }

     public VehicleDaysPrice getInfo(String vehicleId){
         Example example = new Example(VehicleDaysPrice.class);
         example.createCriteria().andEqualTo("vehicleId",vehicleId).andEqualTo("isDel",0).andEqualTo("status",1);
         List<VehicleDaysPrice> list = selectByExample(example);
         if (list.size() > 0){
             return  list.get(0);
         }
         return  null;
     }


     public  List<VehicleDaysPriceVo>  getListByVehicleId(String vehicleId){
         VehicleDaysPrice vehicleDaysPrice = getInfo(vehicleId);
         List<VehicleDaysPriceVo> priceVos = null;
         if (vehicleDaysPrice != null ) {
             priceVos = JSONArray.parseArray(vehicleDaysPrice.getPriceJson(), VehicleDaysPriceVo.class);
         }
         return priceVos;
     }

     public  Vehicle  getVehiclePrice(String vehicleId,Integer days){
         Vehicle vehicle = vehicleBiz.selectById(vehicleId);
         List<VehicleDaysPriceVo> priceVos = getListByVehicleId(vehicleId);
         BigDecimal price = vehicle.getPrice();
         BigDecimal maxPrice = vehicle.getHolidayPrice();
         if (priceVos != null  && priceVos.size() > 0){
             VehicleDaysPriceVo vehicleDaysPriceVo;
             VehicleDaysPriceVo maxVehicleDaysPriceVo;
             if (days == null || days == 0){
                 vehicleDaysPriceVo = priceVos.stream().min(Comparator.comparing(VehicleDaysPriceVo::getPrice)).get();
                 maxVehicleDaysPriceVo = priceVos.stream().max(Comparator.comparing(VehicleDaysPriceVo::getPrice)).get();
             }else {
                 vehicleDaysPriceVo = priceVos.stream().filter(x -> x.getStartDay() <= days && (x.getEndDay() == -1 || x.getEndDay() >= days)).min(Comparator.comparing(VehicleDaysPriceVo::getPrice)).get();
                 maxVehicleDaysPriceVo = priceVos.stream().filter(x -> x.getStartDay() <= days && (x.getEndDay() == -1 || x.getEndDay() >= days)).max(Comparator.comparing(VehicleDaysPriceVo::getPrice)).get();
             }
             if (vehicleDaysPriceVo != null )
                 price = vehicleDaysPriceVo.getPrice();
             if (maxVehicleDaysPriceVo != null )
                 maxPrice = maxVehicleDaysPriceVo.getPrice();
         }
         vehicle.setPrice(price);
         vehicle.setHolidayPrice(maxPrice);
         return  vehicle;
     }













}
